@@ -11,6 +11,11 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
+# Specify whether to us an alternate function when the "hot key"
+# given by altButton is pressed.
+useAlt = False
+altButton = "B"
+
 # Some useful key names:
 #   Up, Down, Left, Right  (D-pad)
 #   Return (this is also the central button of the D-pad)
@@ -106,3 +111,4 @@ altMappingD={
     'GL': ["a Left"],
     'GR': ["a Right"]
     }
+
